Matrix

Struct Matrix 

#[repr(C)]
pub struct Matrix<T, const ROW: usize, const COL: usize> { pub columns: Vector<Vector<T, ROW>, COL>, }
ROW rows, COL columns.

Can be indexed matrix[row][col]

Fields

columns: Vector<Vector<T, ROW>, COL>

Implementations

Source

impl<T, const ROW: usize> Matrix<T, ROW, 1>

pub const fn from_vector(vector: Vector<T, ROW>) -> Matrix<T, ROW, 1>

From a Mx1 vector

Source

impl<T, const ROW: usize, const COL: usize> Matrix<T, ROW, COL>

pub fn from_fn<F>(column_then_row: F) -> Matrix<T, ROW, COL>
where F: FnMut(Vector<i32, 2>) -> T,

Create a matrix from a fn((columns,row))

pub fn from_col_fn<F>(column_then_row: F) -> Matrix<T, ROW, COL>
where F: FnMut(usize, usize) -> T,

pub fn from_row_fn<F>(row_then_column: F) -> Matrix<T, ROW, COL>
where F: FnMut(usize, usize) -> T,

pub const fn from_col( columns: Vector<Vector<T, ROW>, COL>, ) -> Matrix<T, ROW, COL>

pub fn from_col_array(columns: [[T; ROW]; COL]) -> Matrix<T, ROW, COL>

pub fn from_row(rows: Vector<Vector<T, COL>, ROW>) -> Matrix<T, ROW, COL>
where T: Copy,

pub fn from_row_array(rows: [[T; COL]; ROW]) -> Matrix<T, ROW, COL>
where T: Copy,

pub fn col(&self) -> Vector<Vector<T, ROW>, COL>
where T: Copy,

pub fn row(&self) -> Vector<Vector<T, COL>, ROW>
where T: Copy,

pub fn iter_col(&self) -> impl Iterator<Item = Vector<T, ROW>>
where Vector<Vector<T, ROW>, COL>: Copy, T: Copy,

pub fn iter_row(&self) -> impl Iterator<Item = Vector<T, COL>>
where Vector<Vector<T, ROW>, COL>: Copy, T: Copy,

pub fn transpose(&self) -> Matrix<T, COL, ROW>
where T: Copy,

Transpose the matrix

use hexga_math::prelude::*;

assert_eq!(
    Mat2::from_col(vector2(vec2(1., 2.), vec2(3., 4.))).transpose(),
    Mat2::from_col(vector2(vec2(1., 3.), vec2(2., 4.)))
);

assert_eq!(
    Mat::<3,2>::from_col(vector2(vec3(1., 2., 3.), vec3(4., 5., 6.))).transpose(),
    Mat::<2,3>::from_col(vector3(vec2(1., 4.), vec2(2., 5.), vec2(3., 6.)))
);
Source

impl<T> Matrix<T, 2, 2>
where Matrix<T, 2, 2>: Copy + Mul<Vector<T, 2>, Output = Vector<T, 2>>, Vector<T, 2>: Into<Vector<T, 1>>,

pub fn transform_relative(self, relative: Vector<T, 1>) -> Vector<T, 1>
where T: Zero,

pub fn transform_position(self, position: Vector<T, 1>) -> Vector<T, 1>
where T: One,

Source

impl<T> Matrix<T, 3, 3>
where Matrix<T, 3, 3>: Copy + Mul<Vector<T, 3>, Output = Vector<T, 3>>, Vector<T, 3>: Into<Vector<T, 2>>,

pub fn transform_relative(self, relative: Vector<T, 2>) -> Vector<T, 2>
where T: Zero,

pub fn transform_position(self, position: Vector<T, 2>) -> Vector<T, 2>
where T: One,

Source

impl<T> Matrix<T, 4, 4>
where Matrix<T, 4, 4>: Copy + Mul<Vector<T, 4>, Output = Vector<T, 4>>, Vector<T, 4>: Into<Vector<T, 3>>,

pub fn transform_relative(self, relative: Vector<T, 3>) -> Vector<T, 3>
where T: Zero,

pub fn transform_position(self, position: Vector<T, 3>) -> Vector<T, 3>
where T: One,

Source

impl<T, const N: usize> Matrix<T, N, N>
where Matrix<T, N, N>: Copy + Mul<Vector<T, N>, Output = Vector<T, N>>,

pub fn transform(self, value: Vector<T, N>) -> Vector<T, N>

The last value/component is 0 if it is a relative/vector/delta, 1 if it is fixed/point/position in math terms.

Source

impl<T, const N: usize> Matrix<T, N, N>
where T: One + Zero + Copy,

pub const IDENTITY: Matrix<T, N, N> = Self::ONE

Same as One

Source

impl<T, const N: usize> Matrix<T, N, N>
where T: Float,

pub fn inverse(self) -> Option<Matrix<T, N, N>>

Inverse the matrix, or return None if the matrix is singular.

use hexga_math::prelude::*;

assert_eq!(Mat2::IDENTITY.inverse(), Some(Mat2::IDENTITY));

// Non inversible matrix
let mut m2 = Mat2::IDENTITY;
m2.set_y(vec2(0., 0.));
assert_eq!(m2.inverse(), None);

let m2 = Mat2::from_col(vector2(vec2(1., 3.), vec2(2., 4.)));
let m2_inv = m2.inverse().unwrap();

assert_eq!(m2 * m2_inv, Mat2::IDENTITY);
Source

impl<T> Matrix<T, 0, 0>
where T: NumberArithmetic + One,

pub fn det(&self) -> T

Source

impl<T> Matrix<T, 1, 1>
where T: NumberArithmetic + One,

pub fn det(&self) -> T

Source

impl<T> Matrix<T, 2, 2>
where T: NumberArithmetic + One,

pub fn det(&self) -> T

Source

impl<T> Matrix<T, 3, 3>
where T: NumberArithmetic + One,

pub fn det(&self) -> T

Source

impl<T> Matrix<T, 4, 4>
where T: NumberArithmetic + One,

pub fn det(&self) -> T

Source

impl<T, const N: usize> Matrix<T, N, N>
where Matrix<T, N, N>: HaveZ<Vector<T, N>> + Zero, T: Float,

the rotation code is mainly based on glam code

pub fn from_rotation_axis( axis: Vector<T, 3>, angle: AngleOf<T>, ) -> Matrix<T, N, N>

pub fn from_rotation_x(angle: AngleOf<T>) -> Matrix<T, N, N>

pub fn from_rotation_y(angle: AngleOf<T>) -> Matrix<T, N, N>

Source

impl<T, const N: usize> Matrix<T, N, N>
where Matrix<T, N, N>: HaveY<Vector<T, N>> + Zero, T: Float,

pub fn from_rotation_z(angle: AngleOf<T>) -> Matrix<T, N, N>

Source

impl<T, const N: usize> Matrix<T, N, N>
where Matrix<T, N, N>: HaveZ<Vector<T, N>> + One, T: Copy + Zero + One,

pub fn from_scale(scale: Vector<T, N>) -> Matrix<T, N, N>

Put an One for the last component

pub fn from_translation(translation: Vector<T, N>) -> Matrix<T, N, N>
where T: Zero + AddAssign,

Put an Zero for the last component

Methods from Deref<Target = Vector<Vector<T, ROW>, COL>>

pub fn have_x(&self) -> bool

pub fn have_y(&self) -> bool

pub fn have_z(&self) -> bool

pub fn have_w(&self) -> bool

pub fn iter(&self) -> impl Iterator<Item = &T>

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

pub fn normalize(&mut self) -> &mut Vector<T, N>

pub fn set_angle(&mut self, angle: AngleOf<T>) -> &mut Vector<T, N>
where Vector<T, N>: HaveY<T>,

set the angle of the (x, y) axis

pub fn set_length(&mut self, length: T)

pub fn move_to(&mut self, target: Vector<T, N>, speed: T) -> bool
where T: PartialOrd, Vector<T, N>: AddAssign,

return a bool to know if the point reached the destination