#[repr(C)]pub struct Matrix<T, const ROW: usize, const COL: usize> {
pub columns: Vector<Vector<T, ROW>, COL>,
}Expand description
ROW rows, COL columns.
Can be indexed matrix[row][col]
Fields
columns: Vector<Vector<T, ROW>, COL>Implementations
Sourceimpl<T, const ROW: usize> Matrix<T, ROW, 1>
impl<T, const ROW: usize> Matrix<T, ROW, 1>
Sourcepub const fn from_vector(vector: Vector<T, ROW>) -> Matrix<T, ROW, 1>
pub const fn from_vector(vector: Vector<T, ROW>) -> Matrix<T, ROW, 1>
From a Mx1 vector
Sourceimpl<T, const ROW: usize, const COL: usize> Matrix<T, ROW, COL>
impl<T, const ROW: usize, const COL: usize> Matrix<T, ROW, COL>
Sourcepub fn from_fn<F>(column_then_row: F) -> Matrix<T, ROW, COL>
pub fn from_fn<F>(column_then_row: F) -> Matrix<T, ROW, COL>
Create a matrix from a fn((columns,row))
pub fn from_col_fn<F>(column_then_row: F) -> Matrix<T, ROW, COL>
pub fn from_row_fn<F>(row_then_column: F) -> Matrix<T, ROW, COL>
pub const fn from_col( columns: Vector<Vector<T, ROW>, COL>, ) -> Matrix<T, ROW, COL>
pub fn from_col_array(columns: [[T; ROW]; COL]) -> Matrix<T, ROW, COL>
pub fn from_row(rows: Vector<Vector<T, COL>, ROW>) -> Matrix<T, ROW, COL>where
T: Copy,
pub fn from_row_array(rows: [[T; COL]; ROW]) -> Matrix<T, ROW, COL>where
T: Copy,
pub fn col(&self) -> Vector<Vector<T, ROW>, COL>where
T: Copy,
pub fn row(&self) -> Vector<Vector<T, COL>, ROW>where
T: Copy,
pub fn iter_col(&self) -> impl Iterator<Item = Vector<T, ROW>>
pub fn iter_row(&self) -> impl Iterator<Item = Vector<T, COL>>
Sourcepub fn transpose(&self) -> Matrix<T, COL, ROW>where
T: Copy,
pub fn transpose(&self) -> Matrix<T, COL, ROW>where
T: Copy,
Transpose the matrix
use hexga_math::prelude::*;
assert_eq!(
Mat2::from_col(vector2(vec2(1., 2.), vec2(3., 4.))).transpose(),
Mat2::from_col(vector2(vec2(1., 3.), vec2(2., 4.)))
);
assert_eq!(
Mat::<3,2>::from_col(vector2(vec3(1., 2., 3.), vec3(4., 5., 6.))).transpose(),
Mat::<2,3>::from_col(vector3(vec2(1., 4.), vec2(2., 5.), vec2(3., 6.)))
);Sourceimpl<T> Matrix<T, 2, 2>
impl<T> Matrix<T, 2, 2>
pub fn transform_relative(self, relative: Vector<T, 1>) -> Vector<T, 1>where
T: Zero,
pub fn transform_position(self, position: Vector<T, 1>) -> Vector<T, 1>where
T: One,
Sourceimpl<T> Matrix<T, 3, 3>
impl<T> Matrix<T, 3, 3>
pub fn transform_relative(self, relative: Vector<T, 2>) -> Vector<T, 2>where
T: Zero,
pub fn transform_position(self, position: Vector<T, 2>) -> Vector<T, 2>where
T: One,
Sourceimpl<T> Matrix<T, 4, 4>
impl<T> Matrix<T, 4, 4>
pub fn transform_relative(self, relative: Vector<T, 3>) -> Vector<T, 3>where
T: Zero,
pub fn transform_position(self, position: Vector<T, 3>) -> Vector<T, 3>where
T: One,
Sourceimpl<T, const N: usize> Matrix<T, N, N>where
T: Float,
impl<T, const N: usize> Matrix<T, N, N>where
T: Float,
Sourcepub fn inverse(self) -> Option<Matrix<T, N, N>>
pub fn inverse(self) -> Option<Matrix<T, N, N>>
Inverse the matrix, or return None if the matrix is singular.
use hexga_math::prelude::*;
assert_eq!(Mat2::IDENTITY.inverse(), Some(Mat2::IDENTITY));
// Non inversible matrix
let mut m2 = Mat2::IDENTITY;
m2.set_y(vec2(0., 0.));
assert_eq!(m2.inverse(), None);
let m2 = Mat2::from_col(vector2(vec2(1., 3.), vec2(2., 4.)));
let m2_inv = m2.inverse().unwrap();
assert_eq!(m2 * m2_inv, Mat2::IDENTITY);Sourceimpl<T, const N: usize> Matrix<T, N, N>
the rotation code is mainly based on glam code
impl<T, const N: usize> Matrix<T, N, N>
the rotation code is mainly based on glam code
pub fn from_rotation_axis( axis: Vector<T, 3>, angle: AngleOf<T>, ) -> Matrix<T, N, N>
pub fn from_rotation_x(angle: AngleOf<T>) -> Matrix<T, N, N>
pub fn from_rotation_y(angle: AngleOf<T>) -> Matrix<T, N, N>
Sourceimpl<T, const N: usize> Matrix<T, N, N>
impl<T, const N: usize> Matrix<T, N, N>
pub fn from_rotation_z(angle: AngleOf<T>) -> Matrix<T, N, N>
Methods from Deref<Target = Vector<Vector<T, ROW>, COL>>
pub fn have_x(&self) -> bool
pub fn have_y(&self) -> bool
pub fn have_z(&self) -> bool
pub fn have_w(&self) -> bool
pub fn iter(&self) -> impl Iterator<Item = &T>
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>
pub fn normalize(&mut self) -> &mut Vector<T, N>
Sourcepub fn set_angle(&mut self, angle: AngleOf<T>) -> &mut Vector<T, N>
pub fn set_angle(&mut self, angle: AngleOf<T>) -> &mut Vector<T, N>
set the angle of the (x, y) axis
pub fn set_length(&mut self, length: T)